# mark.js

#### :sparkles: formerly known as jquery.mark or jmHighlight :sparkles:

##### Highlight keywords using JavaScript. Intended for every use case. <br> Can e.g. be used to mark text in search results.

[![Build Status][build-status-image]][build-status]
[![Code quality][code-quality-image]][code-quality]
[![npm Version][npm-version-image]][npm-version]
[![Bower Version][bower-version-image]][bower-version]
[![License][license-image]][license]
[![jsDelivr Hits][jsdelivr-image]][jsdelivr]
[![Greenkeeper][greenkeeper-image]][greenkeeper]  
<a href="https://saucelabs.com/u/markjs">
  <img src="https://saucelabs.com/browser-matrix/markjs.svg" alt="Sauce Test Status" width="741" />
</a>

## Documentation and Further Information

**Please view the [website][website] for documentation and further information!**

## Contributing

See the [contribution guidelines][contributing].

## Changelog
Changes are documented in [release][releases] descriptions.  
You want to be notified about new releases? Click the "Subscribe to releases"
button on [libraries.io][libraries].

---

Happy hacking!

[build-status]: https://travis-ci.org/julmot/mark.js
[code-quality]: https://www.codacy.com/app/julmot/mark.js
[npm-version]: https://www.npmjs.com/package/mark.js
[bower-version]: https://github.com/julmot/mark.js
[license]: https://raw.githubusercontent.com/julmot/mark.js/master/LICENSE
[jsdelivr]: https://www.jsdelivr.com/package/npm/mark.js
[greenkeeper]: https://github.com/julmot/mark.js

[build-status-image]: https://img.shields.io/travis/julmot/mark.js/master.svg?label=test
[code-quality-image]:https://img.shields.io/codacy/27a3ed45370f41e89b02073b214c18a7.svg
[npm-version-image]: https://img.shields.io/npm/v/mark.js.svg
[bower-version-image]: https://img.shields.io/bower/v/mark.js.svg
[license-image]: https://img.shields.io/badge/license-MIT-blue.svg
[jsdelivr-image]: https://data.jsdelivr.com/v1/package/npm/mark.js/badge?style=rounded
[greenkeeper-image]: https://badges.greenkeeper.io/julmot/mark.js.svg

[website]: https://markjs.io/
[contributing]: https://github.com/julmot/mark.js/blob/master/CONTRIBUTING.md
[releases]: https://github.com/julmot/mark.js/releases
[libraries]: https://libraries.io/bower/mark.js/
